Security Policy
---------------

Supported Versions
==================

Always update to the latest version of
this Action to keep up with security patches.

Reporting a Vulnerability
=========================

Email to ``wk+gh-action-pypi-publish-security``
at ``sydorenko`` dot ``org`` dot ``ua``.
